#include <stdio.h>

int main()
{
  int i = 3, j = 6;
  int *p1, *p2;

  p1 = &i;
  p2 = &j;
  *p1 = *p2;
 fprintf(stdout,"L'entier i=%d est à l'adresse %p\n",i,&i);
 fprintf(stdout,"L'entier j=%d est à l'adresse %p\n",j,&j);
 fprintf(stdout,"Le pointer p1=%p est à l'adresse %p\n",p1,&p2);
 fprintf(stdout,"Le pointer p2=%p est à l'adresse %p\n",p2,&p1);
}
