#include <stdio.h>
#include <stdlib.h>
#include "list.h"

ELEMLIST *new_list(int val)
{
  ELEMLIST *res;

  res=(ELEMLIST*)malloc(sizeof(ELEMLIST));
  if (res==0)
    { /* toujours tester le résultat d'un appel systeme */
      printf("erreur: plus d'espace disponible\n");
      exit(1);
    }
  res->val=val;
  res->suivant=NULL;
  return res;
}

LISTE ajouterliste(LISTE liste1, int val)
{
  ELEMLIST *res;

  res=new_list(val);
  res -> suivant = liste1;
  return res;
}

void afficher_list(ELEMLIST *liste)
{
  if  (liste!=NULL)
    {
      printf(" -> [%d]",liste->val);
      afficher_list(liste->suivant);
    }
  else{
    printf("\n");
  }
}

int main()
{
  ELEMLIST *a;
  
  a=new_list(5);
  a=ajouterliste(a,6);
  a=ajouterliste(a,7);
  afficher_list(a);
  
  
  return 0;
  
}
